# -*- coding: utf-8 -*-
# Copyright © 2007 Lateef Alabi-Oki
#
# This file is part of striim.
#
# striim is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# striim is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with striim; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

"""
This module documents a class that creates the DBus object for striim.

@author: Lateef Alabi-Oki
@organization: The striim Project
@copyright: Copyright © 2007 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

from dbus.service import Object, method, BusName
from Global import dbus_service_name

class DBusService(Object):
	"""
	This class ensures only one instance of striim is ever initialized.
	"""

	def __init__(self, manager):
		"""
		Initialize the D-Bus service.

		@param self: Reference to the DBusService instance.
		@type self: A DBusService object.

		@param manager: Reference to striim's instance manager.
		@type manager: An InstanceManager object.
		"""
		from Global import session_bus, dbus_object_path
		bus_name = BusName(dbus_service_name, bus=session_bus)
		Object.__init__(self, bus_name, dbus_object_path)
		self.__manager = manager

	@method(dbus_service_name)
	def show_player(self, argv):
		"""
		Show the radio player
		
		@param self: Reference to the DBusService instance.
		@type self: A DBusService object.
		"""
		return self.__manager.show_player(argv)
